.. Lace documentation master file, created by
   sphinx-quickstart on Tue Feb 28 16:57:05 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. py:module:: lace

Welcome to Lace's documentation!
================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   lace.engine
   lace.analysis
   lace.plot

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
